@@ -76,7 +76,7 @@ class NxPyDocs():
                 else:
                     click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
             else:
-                if self.filetype != "json" or "yaml":
+                if self.filetype == "json" or "yaml":
                     command_output = clid( '%s' % self.command )
                     parsed_json = json.loads(command_output)                    
                     if self.repo != "none":
